Struct diem_config::keys::ConfigKey [−][src]
pub struct ConfigKey<T: PrivateKey + Serialize> { /* fields omitted */ }Expand description
ConfigKey places a clonable wrapper around PrivateKeys for config purposes only. The only time configs have keys is either for testing or for low security requirements. Diem recommends that keys be stored in key managers. If we make keys unclonable, then the configs must be mutable and that becomes a requirement strictly as a result of supporting test environments, which is undesirable. Hence this internal wrapper allows for keys to be clonable but only from configs.
Implementations